@@ -11,7 +11,7 @@ pub fn get_feed<'a>(switchboard_feed: &'a AccountInfo<'a>) -> Result<RoundResult
         deserialize_from_slice(&state_buffer[1..]).map_err(|_| ProgramError::InvalidAccountData)?;
     let mut maybe_round = aggregator_state.current_round_result.clone();
     if (maybe_round.is_none()
-        || maybe_round.clone().unwrap().num_success < aggregator_state.min_confirmations)
+        || maybe_round.clone().unwrap().num_success < aggregator_state.configs.ok_or(ProgramError::InvalidAccountData)?.min_confirmations)
         && aggregator_state.last_round_result.is_some()
     {
         maybe_round = aggregator_state.last_round_result.clone();
